import 'package:flutter/material.dart';

enum ApplyTextDecoration { altiCizili, ustuCizili, yazininUstuCizili }

class OText extends StatelessWidget {
  @required
  String text;
  double size;
  double fontWeight;
  double wordSpacing;
  Color color;
  Color decorationColor;
  Color backgrounColor;
  ApplyTextDecoration textDecoration;

  OText(
    this.text, {
    this.size,
    this.color,
    this.decorationColor,
    this.backgrounColor,
    this.textDecoration,
    this.fontWeight,
    this.wordSpacing,
  }) : assert(text != null);

  @override
  Widget build(BuildContext context) {
    return Container(
      child: Text(
        text ?? "",
        style: TextStyle(
          fontSize: size ?? 16,
          color: color ?? Theme.of(context).accentColor,
          decoration: _getDecoration(),
          decorationColor: decorationColor ?? Theme.of(context).accentColor,
          backgroundColor: backgrounColor ?? Colors.transparent,
          fontWeight: fontWeight ?? FontWeight.normal,
          wordSpacing: wordSpacing ?? 0,
        ),
      ),
    );
  }

  _getDecoration() {
    if (textDecoration == ApplyTextDecoration.altiCizili) {
      return TextDecoration.underline;
    } else if (textDecoration == ApplyTextDecoration.ustuCizili) {
      return TextDecoration.overline;
    } else if (textDecoration == ApplyTextDecoration.yazininUstuCizili) {
      return TextDecoration.lineThrough;
    } else {
      return TextDecoration.none;
    }
  }
}

class OTextFormField extends StatelessWidget {
  TextEditingController controller;
  String validator;
  Color textColor;
  Color backgorundColor;
  String label;
  Color labelColor;
  String hint;
  String yaziSagdaki;
  Color hintColor;
  Color borderColor;
  Color seciliBorderColor;
  double borderWitdh = 0;
  int maxLine;
  double fontSize;
  double borderRadius;
  TextInputType klavyeGirisBicimi;
  Icon iconSoldaki;
  Icon iconSagdaki;
  double paddingBottom;

  OTextFormField({
    this.textColor,
    this.seciliBorderColor,
    this.validator,
    this.iconSoldaki,
    this.backgorundColor,
    this.borderColor,
    this.borderRadius,
    this.borderWitdh = 0,
    this.controller,
    this.fontSize,
    this.hint,
    this.hintColor,
    this.iconSagdaki,
    this.klavyeGirisBicimi,
    this.label,
    this.labelColor,
    this.maxLine,
    this.yaziSagdaki = "",
    this.paddingBottom = 0,
  });

  @override
  Widget build(BuildContext context) => Padding(
        padding: EdgeInsets.only(bottom: paddingBottom),
        child: TextFormField(
          keyboardType: klavyeGirisBicimi ?? TextInputType.text,
          validator: (value) {
            if (value == null || value.isEmpty) {
              return validator;
            }
            return "Lütfen boş bırakmayın";
          },
          controller: controller,
          autofocus: false,
          focusNode: FocusNode(),
          maxLines: maxLine ?? 1,
          style:
              TextStyle(color: textColor ?? Colors.black, fontSize: fontSize),
          decoration: InputDecoration(
            labelText: label,
            enabledBorder: OutlineInputBorder(
              // Border rengi ve özellikleri
              borderSide: borderColor == null
                  ? BorderSide(
                      //Uygulamanın ana renklerini kullan
                      //color: Theme.of(context).accentColor,
                      color: Colors.transparent,
                      width: 0,
                    )
                  : BorderSide(
                      color: borderColor,
                      width: borderWitdh,
                    ),
              borderRadius: borderRadius == null
                  ? BorderRadius.all(Radius.circular(10))
                  : BorderRadius.all(Radius.circular(borderRadius)),
            ),
            focusedBorder: OutlineInputBorder(
              //Tıklandığında
              borderSide: seciliBorderColor == null
                  ? BorderSide(color: Theme.of(context).accentColor)
                  : BorderSide(color: seciliBorderColor),
              borderRadius: borderRadius == null
                  ? BorderRadius.all(Radius.circular(10))
                  : BorderRadius.all(Radius.circular(borderRadius)),
            ),
            labelStyle: TextStyle(
              color: labelColor ?? Colors.black,
            ),
            hintText: hint,
            hintStyle: TextStyle(
              color: hintColor ?? Colors.grey[500],
            ),
            prefixIcon: iconSoldaki ?? null,
            suffixIcon: iconSagdaki ?? null,
            filled: true,
            suffixText: yaziSagdaki,
            fillColor: backgorundColor ?? Colors.white,
            border: OutlineInputBorder(
              borderRadius: borderRadius == null
                  ? BorderRadius.all(Radius.circular(10))
                  : BorderRadius.all(Radius.circular(borderRadius)),
            ),
          ),
        ),
      );
}


class ODialog {
  showDiyalog(
    BuildContext context, {
    double margin,
    double marginVertical,
    double marginHorizontal,
    double padding,
    Color backgroundColor,
    Widget child,
    double borderWidth,
    double borderRadius,
    Color borderColor,
  }) {
    return showDialog(
        context: context,
        builder: (context) {
          return Dialog(
            shape: RoundedRectangleBorder(
                side: BorderSide(
                  color: borderColor ?? Colors.transparent,
                  width: borderWidth ?? 0,
                  style: BorderStyle.solid,
                ),
                borderRadius: BorderRadius.all(
                  Radius.circular(borderRadius ?? 0),
                )),
            backgroundColor: backgroundColor ?? Theme.of(context).dialogBackgroundColor,
            //insetPadding: EdgeInsets.all(margin ?? 4),
            insetPadding: margin == null
                ? EdgeInsets.symmetric(vertical: marginVertical ?? 8, horizontal: marginHorizontal ?? 8)
                : EdgeInsets.all(margin),
            child: Container(
              //color: backgroundColor ?? Theme.of(context).dialogBackgroundColor,
              padding: EdgeInsets.all(padding ?? 8),
              width: double.infinity,
              height: double.infinity,
              child: child ?? Container(),
            ),
          );
        });
  }
}